/**
 * 获取指定时间范围的开始时间和结束时间
 * @param {("daily" | "weekly")} timeScope - 时间范围，可以是 "daily" 或 "weekly"
 * @returns {{ startTime: string, endTime: string }} - 格式化后的开始时间和结束时间
 */
export const getTimeRange = (timeScope: "daily" | "weekly") => {
  const formatDate = (date: Date) => {
    const pad = (num: number) => (num < 10 ? "0" + num : num)
    return `${date.getFullYear()}-${pad(date.getMonth() + 1)}-${pad(date.getDate())} ${pad(date.getHours())}:${pad(date.getMinutes())}:${pad(date.getSeconds())}`
  }

  const now = new Date()
  const startTime = new Date(now)
  if (timeScope === "daily") {
    startTime.setHours(0, 0, 0, 0)
  } else {
    const day = now.getDay()
    const diff = day === 0 ? 6 : day - 1 // adjust when day is sunday
    startTime.setDate(now.getDate() - diff)
    startTime.setHours(0, 0, 0, 0)
  }

  const endTime = new Date(now)
  endTime.setHours(23, 59, 59, 999)

  return {
    startTime: formatDate(startTime),
    endTime: formatDate(endTime),
  }
}
